@@ -12,6 +12,14 @@ class InvalidDirectoryPath(Exception):
     pass
 
 
+class LargePayloadExc(Exception):
+    pass
+
+
+class DBError(Exception):
+    pass
+
+
 class APIError(Exception):
     def __str__(self):
         return '"%s"' % self.args
