@@ -5,10 +5,10 @@
 
 from flask import Flask, request
 
-from .data import present_swhids
-
 from swh.web.common.exc import LargePayloadExc
 
+from .data import present_swhids
+
 
 def create_app():
     app = Flask(__name__)
@@ -19,7 +19,7 @@ def create_app():
 
         if len(swhids) > 900:
             raise LargePayloadExc(
-                "The maximum number of PIDs this endpoint " "can receive is 900"
+                "The maximum number of SWHIDs this endpoint can receive is 900"
             )
 
         res = {swhid: {"known": False} for swhid in swhids}
